==> pylinuxauto-2024.7.11-py3-none-any.whl: pylinuxauto/attr/__init__.py <==
#!/usr/bin/env python3
# _*_ coding:utf-8 _*_
# SPDX-FileCopyrightText: 2023 UnionTech Software Technology Co., Ltd.
# SPDX-License-Identifier: GPL-2.0-only

from funnylog2 import logger

from pylinuxauto.attr.depends import install_depends

install_depends()

from pylinuxauto.attr.dogtail.tree import SearchError
from pylinuxauto.attr.dogtail.tree import root
from pylinuxauto.attr.dogtail.config import config
from pylinuxauto.attr.dogtail.tree import Node
from pylinuxauto.exceptions import ElementNotFound


class Attr():
    __author__ = "mikigo<huangmingqiang@uniontech.com>"

    def __init__(self, appname=None):
        config.childrenLimit = 10000
        config.logDebugToFile = False
        config.searchCutoffCount = 2
        config.logDebugToStdOut = False
        self.appname = appname
        if appname:
            self.obj = root.application(appname)
        else:
            self.obj = root

    def __find_child(self, obj, *args, **kwargs):
        try:
            return obj.child(*args, **kwargs)
        except SearchError:
            raise ElementNotFound(*args, **kwargs)

    def find_element_by_attr_name(
            self,
            *,
            appname: str = "",
            name: str = "",
            role_name: str = "",
            description: str = "",
            label: str = "",
            recursive: bool = True,
            retry: bool = False,
            debugName: str = None,
            showingOnly=None
    ) -> Node:
        logger.debug(f"获取元素对象【{name}】")
        if appname:
            self.obj = root.application(appname)
        element = self.__find_child(
            self.obj,
            name,
            roleName=role_name,
            description=description,
            label=label,
            recursive=recursive,
            retry=retry,
            debugName=debugName,
            showingOnly=showingOnly
        )
        logger.debug(f"获取到元素对象【{name}】:{element}")
        return element

    def find_element_by_attr_path(self, attr_path: str):
        if not attr_path.startswith("/"):
            raise ValueError
        elements = [i for i in attr_path.split("/") if i]
        _obj = self.obj
        for ele in elements:
            print(_obj)
            _obj = self.__find_child(_obj, ele)
        return _obj


if __name__ == '__main__':
    dog = Attr().find_element_by_attr_name(appname="dde-dock", name="Btn_文件管理器").click()

==> pylinuxauto-2024.7.16-py3-none-any.whl: pylinuxauto/attr/__init__.py <==
#!/usr/bin/env python3
# _*_ coding:utf-8 _*_
# SPDX-FileCopyrightText: 2023 UnionTech Software Technology Co., Ltd.
# SPDX-License-Identifier: GPL-2.0-only

from funnylog2 import logger
from pylinuxauto import exceptions

from pylinuxauto.attr.depends import install_depends

install_depends()

from pylinuxauto.attr.dogtail.tree import SearchError
from pylinuxauto.attr.dogtail.tree import root
from pylinuxauto.attr.dogtail.config import config
from pylinuxauto.attr.dogtail.tree import Node
from pylinuxauto.exceptions import ElementNotFound


class Attr():
    __author__ = "mikigo<huangmingqiang@uniontech.com>"

    def __init__(self, appname=None):
        config.childrenLimit = 10000
        config.logDebugToFile = False
        config.searchCutoffCount = 2
        config.logDebugToStdOut = False
        self.appname = appname
        if appname:
            self.obj = root.application(appname)
        else:
            self.obj = root

    def __find_child(self, obj, *args, **kwargs):
        try:
            return obj.child(*args, **kwargs, retry=False)
        except SearchError:
            raise ElementNotFound(*args, **kwargs)

    def find_element_by_attr_name(
            self,
            *,
            appname: str = "",
            name: str = "",
            role_name: str = "",
            description: str = "",
            label: str = "",
            recursive: bool = True,
            retry: bool = False,
            debugName: str = None,
            showingOnly=None
    ) -> Node:
        logger.debug(f"获取元素对象【{name}】")
        if appname:
            self.obj = root.application(appname)
        element = self.__find_child(
            self.obj,
            name,
            roleName=role_name,
            description=description,
            label=label,
            recursive=recursive,
            retry=retry,
            debugName=debugName,
            showingOnly=showingOnly
        )
        logger.debug(f"获取到元素对象【{name}】:{element}")
        return element

    def find_element_by_attr_path(self, attr_path: str):
        if not attr_path.startswith("/"):
            raise ValueError
        elements = [i for i in attr_path.split("/") if i]
        if not elements:
            raise ValueError
        try:
            _obj = root.application(elements[0], retry=False)
        except SearchError:
            raise exceptions.ApplicationStartError(elements[0])
        for ele in elements[1:]:
            _obj = self.__find_child(_obj, ele)
        return _obj


if __name__ == '__main__':
    dog = Attr().find_element_by_attr_name(appname="dde-dock", name="Btn_文件管理器").click()
